/**
 *
 * Copyright 2015 Florian Schmaus
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jivesoftware.smack.tcp;

import java.util.concurrent.atomic.AtomicBoolean;


public class BundleAndDefer {

    private final AtomicBoolean isStopped;

    BundleAndDefer(AtomicBoolean isStopped) {
        this.isStopped = isStopped;
    }

    /**
     * Stop the bundle and defer mechanism that was started when this instance of {@link BundleAndDefer} was emitted by
     * Smack.
     * <p>
     * It is possible that the defer period already expired when this is invoked. In this case this method is basically
     * a no-op.
     * </p>
     */
    public void stopCurrentBundleAndDefer() {
        synchronized (isStopped) {
            if (isStopped.get()) {
                return;
            }
            isStopped.set(true);
            isStopped.notify();
        }
    }
}
